@@ -1,5 +1,5 @@
 /* This file is part of GNU Dico.
-   Copyright (C) 1998-2018 Sergey Poznyakoff
+   Copyright (C) 1998-2020 Sergey Poznyakoff
 
    GNU Dico is free software; you can redistribute it and/or modify
    it under the terms of the GNU General Public License as published by
@@ -14,9 +14,7 @@
    You should have received a copy of the GNU General Public License
    along with GNU Dico.  If not, see <http://www.gnu.org/licenses/>. */
 
-#ifdef HAVE_CONFIG_H
-# include <config.h>
-#endif
+#include <config.h>
 #include <dico.h>
 #include <dico/udb.h>
 #include <sys/types.h>
@@ -84,7 +82,7 @@ dico_udb_get_groups(dico_udb_t db, const char *key, dico_list_t *groups)
 dico_list_t /* of struct dico_udb_def */ dico_udb_def_list;
 
 static int
-udb_def_cmp(const void *item, void *data)
+udb_def_cmp(const void *item, const void *data, void *ignore)
 {
     const struct dico_udb_def *def = item;
     const char *proto = data;
@@ -100,7 +98,7 @@ dico_udb_define(struct dico_udb_def *dptr)
 	    errno = ENOMEM;
 	    return 1;
 	}
-	dico_list_set_comparator(dico_udb_def_list, udb_def_cmp);
+	dico_list_set_comparator(dico_udb_def_list, udb_def_cmp, NULL);
     }
     return dico_list_append(dico_udb_def_list, dptr);
 }
