@@ -1,5 +1,5 @@
 ;;;; This file is part of GNU Dico.
-;;;; Copyright (C) 2008, 2010 Sergey Poznyakoff
+;;;; Copyright (C) 2008-2020 Sergey Poznyakoff
 ;;;; 
 ;;;; GNU Dico is free software; you can redistribute it and/or modify
 ;;;; it under the terms of the GNU General Public License as published by
@@ -44,6 +44,12 @@
 (define (result-count rh)
   #f)
 
+(define (result-headers rh hdr)
+  (list))
+
+(define (db-mime-header dbh)
+  #f)
+
 (define-public (dico-init arg)
   (list (cons "open" open-module)
         (cons "close" close-module)
@@ -53,4 +59,6 @@
         (cons "define" define-word)
         (cons "match" match-word)
         (cons "output" output)
-        (cons "result-count" result-count)))
+        (cons "result-count" result-count)
+	(cons "result-headers" result-headers)
+	(cons "db-mime-header" db-mime-header)))
